@@ -3,7 +3,7 @@ package tui
 import (
 	"fmt"
 
-	"github.com/dundee/gdu/v5/pkg/analyze"
+	"github.com/dundee/gdu/v5/pkg/fs"
 	"github.com/gdamore/tcell/v2"
 )
 
@@ -114,6 +114,13 @@ func (ui *UI) keyPressed(key *tcell.EventKey) *tcell.EventKey {
 			ui.showDir()
 			ui.table.Select(row, column)
 		}
+	case 'B':
+		ui.ShowRelativeSize = !ui.ShowRelativeSize
+		if ui.currentDir != nil {
+			row, column := ui.table.GetSelection()
+			ui.showDir()
+			ui.table.Select(row, column)
+		}
 	case 'c':
 		ui.showItemCount = !ui.showItemCount
 		if ui.currentDir != nil {
@@ -175,8 +182,8 @@ func (ui *UI) handleDelete(shouldEmpty bool) {
 	}
 	// do not allow deleting parent dir
 	row, column := ui.table.GetSelection()
-	selectedFile := ui.table.GetCell(row, column).GetReference().(analyze.Item)
-	if selectedFile == ui.currentDir.Parent {
+	selectedFile := ui.table.GetCell(row, column).GetReference().(fs.Item)
+	if selectedFile == ui.currentDir.GetParent() {
 		return
 	}
 
