@@ -13,6 +13,8 @@ func (ui *UI) showDir() {
 	var (
 		totalUsage int64
 		totalSize  int64
+		maxUsage   int64
+		maxSize    int64
 		itemCount  int
 	)
 
@@ -28,7 +30,7 @@ func (ui *UI) showDir() {
 	rowIndex := 0
 	if ui.currentDirPath != ui.topDirPath {
 		cell := tview.NewTableCell("                         [::b]/..")
-		cell.SetReference(ui.currentDir.Parent)
+		cell.SetReference(ui.currentDir.GetParent())
 		cell.SetStyle(tcell.Style{}.Foreground(tcell.ColorDefault))
 		ui.table.SetCell(0, 0, cell)
 		rowIndex++
@@ -36,7 +38,21 @@ func (ui *UI) showDir() {
 
 	ui.sortItems()
 
-	for i, item := range ui.currentDir.Files {
+	if ui.ShowRelativeSize {
+		for _, item := range ui.currentDir.GetFiles() {
+			if item.GetUsage() > maxUsage {
+				maxUsage = item.GetUsage()
+			}
+			if item.GetSize() > maxSize {
+				maxSize = item.GetSize()
+			}
+		}
+	} else {
+		maxUsage = ui.currentDir.GetUsage()
+		maxSize = ui.currentDir.GetSize()
+	}
+
+	for i, item := range ui.currentDir.GetFiles() {
 		if ui.filterValue != "" && !strings.Contains(
 			strings.ToLower(item.GetName()),
 			strings.ToLower(ui.filterValue),
@@ -48,9 +64,9 @@ func (ui *UI) showDir() {
 		totalSize += item.GetSize()
 		itemCount += item.GetItemCount()
 
-		cell := tview.NewTableCell(ui.formatFileRow(item))
+		cell := tview.NewTableCell(ui.formatFileRow(item, maxUsage, maxSize))
 		cell.SetStyle(tcell.Style{}.Foreground(tcell.ColorDefault))
-		cell.SetReference(ui.currentDir.Files[i])
+		cell.SetReference(ui.currentDir.GetFiles()[i])
 
 		ui.table.SetCell(rowIndex, 0, cell)
 		rowIndex++
